// *************************************************************************************
// SCICHART® Copyright SciChart Ltd. 2011-2023. All rights reserved.
//  
// Web: http://www.scichart.com
//   Support: support@scichart.com
//   Sales:   sales@scichart.com
// 
// AddObjectsToA3DChart.xaml.cs is part of the SCICHART® Examples. Permission is hereby granted
// to modify, create derivative works, distribute and publish any part of this source
// code whether for commercial, private or personal use. 
// 
// The SCICHART® examples are distributed in the hope that they will be useful, but
// without any warranty. It is provided "AS IS" without warranty of any kind, either
// expressed or implied. 
// *************************************************************************************
using System;
using System.Drawing.Imaging;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using SciChart.Charting3D;
using SciChart.Charting3D.Axis;
using SciChart.Charting3D.Model;
using SciChart.Charting3D.Visuals.Object;

namespace SciChart.Examples.Examples.Charts3D.Customize3DChart
{
    public partial class AddObjectsToA3DChart : UserControl
    {
        public AddObjectsToA3DChart()
        {
            InitializeComponent();

            var dataSeries = new UniformGridDataSeries3D<double>(9, 9);

            for (int x = 0; x < 9; x++)
            {
                for (int z = 0; z < 9; z++)
                {
                    if (z % 2 == 0)
                    {
                        dataSeries[z, x] = (x % 2 == 0 ? 1 : 4);
                    }
                    else
                    {
                        dataSeries[z, x] = (x % 2 == 0 ? 4 : 1);
                    }
                }
            }

            surfaceMeshRenderableSeries.DataSeries = dataSeries;

            var objectUri = new Uri("pack://application:,,,/Knight_Low.obj");
            var objectStream = Application.GetResourceStream(objectUri).Stream;

            var textureUri = new Uri("pack://application:,,,/WhiteWoodTexture.jpg");
            var textureStream = Application.GetResourceStream(textureUri).Stream;

            // Create Object
            var object3D = new ObjectModel3D(objectStream, System.Windows.Media.Colors.Aqua);

            // Add Object
            sciChart3DSurface.SceneObjects.Add(object3D);

            object3D.Position = new Vector3(0.2f, 0.2f, 0.2f);
            object3D.CoordinateMode = ObjectCoordinateMode.Relative;
            object3D.Scale = new Vector3(0.2f, 0.2f, 0.2f);
        }

        private void AddObject_Click(object sender, RoutedEventArgs e)
        {
            var objectUri = new Uri("pack://application:,,,/Knight_Low.obj");
            var objectStream = Application.GetResourceStream(objectUri).Stream;

            var textureUri = new Uri("pack://application:,,,/WhiteWoodTexture.jpg");
            var textureStream = Application.GetResourceStream(textureUri).Stream;

            // Create Object
            var object3D = new ObjectModel3D(objectStream, textureStream);

            // Add Object
            sciChart3DSurface.SceneObjects.Add(object3D);

            object3D.Position = new Vector3(0.2f, 0.3f, 0.3f);
            object3D.CoordinateMode = ObjectCoordinateMode.Relative;
            object3D.Scale = new Vector3(0.2f, 0.2f, 0.2f);

            var rotation = new Rotation3D()
            {
                Angle = 90,
                Axis = Axis3D.YAxis
            };
            object3D.Rotation = rotation;
        }

        private void Remove_Click(object sender, RoutedEventArgs e)
        {
            sciChart3DSurface.SceneObjects.Clear();
            // Call ZoomExtents() to force re-draw
            sciChart3DSurface.ZoomExtents(); 
            // or you can use InvalidateElement() method for same reason
            // sciChart3DSurface.InvalidateElement();
        }
    }
}